"""
FreeSurfer

FreeSurfer is a software package for the analysis and visualization of
neuroimaging data from cross-sectional and longitudinal studies. It is developed
by the Laboratory for Computational Neuroimaging at the Martinos Center for
Biomedical Imaging.

FreeSurfer provides full processing streams for structural and functional MRI
and includes tools for linear and nonlinear registration, cortical and
subcortical segmentation, cortical surface reconstruction, statistical analysis
of group morphometry, diffusion MRI, PET analysis, and much more. It is also the
structural MRI analysis software of choice for the Human Connectome Project.

URL: https://github.com/freesurfer/freesurfer
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .analyzeto4dfp import *
from .anatomi_cuts_utils import *
from .annot2std import *
from .ants_denoise_image_fs import *
from .ants_n4_bias_field_correction_fs import *
from .aparc2feat import *
from .aparc_stats_aseg import *
from .aparcstats2table import *
from .aparcstatsdiff import *
from .apas2aseg import *
from .apply_morph import *
from .aseg2feat import *
from .asegstats2table import *
from .asegstatsdiff import *
from .avi2talxfm import *
from .bblabel import *
from .bbmask import *
from .bbregister import *
from .bedpostx_mgh import *
from .bet_fsl import *
from .beta2sxa import *
from .biasfield import *
from .bmedits2surf import *
from .brec import *
from .browse_minc_header_tcl import *
from .bugr import *
from .build_desikan_killiany_gcs_csh import *
from .cblumwmgyri import *
from .check_mcr_sh import *
from .check_recons_sh import *
from .check_subject import *
from .compute_interrater_variability_csh import *
from .compute_label_volumes_csh import *
from .compute_vox2vox import *
from .conf2hires import *
from .connected_components import *
from .cor_to_minc import *
from .cp_dicom import *
from .create_morph import *
from .csvprint import *
from .dcmdir_info_mgh import *
from .dcmdjpeg_fs import *
from .dcmdrle_fs import *
from .dcmsplit import *
from .dcmunpack import *
from .deface_subject import *
from .defect2seg import *
from .defect_seg import *
from .dicom_rename import *
from .diffusion_utils import *
from .dmri_ac_sh import *
from .dmri_anatomi_cuts import *
from .dmri_bset import *
from .dmri_colored_fa import *
from .dmri_extract_surface_measurements import *
from .dmri_forrest import *
from .dmri_group import *
from .dmri_group_by_endpoints import *
from .dmri_match import *
from .dmri_mergepaths import *
from .dmri_motion import *
from .dmri_neighboring_regions import *
from .dmri_paths import *
from .dmri_pathstats import *
from .dmri_project_end_points import *
from .dmri_save_histograms import *
from .dmri_spline import *
from .dmri_stats_ac import *
from .dmri_train import *
from .dmri_trk2trk import *
from .dmri_violin_plots import *
from .dmri_vox2vox import *
from .dt_recon import *
from .epidewarp_fsl import *
from .export_gcam import *
from .extract_seg_waveform import *
from .exvivo_hemi_proc import *
from .feat2segstats import *
from .feat2surf import *
from .fiducials_calibration import *
from .fiducials_correction import *
from .fix_subject import *
from .fix_subject_corrected import *
from .fix_subject_corrected_rh import *
from .fix_subject_rh import *
from .fixup_mni_paths import *
from .flip_4dfp import *
from .flirt_fsl import *
from .flirt_newdefault_20080811_sch import *
from .fname2ext import *
from .fname2stem import *
from .freeview import *
from .fs_check_version import *
from .fs_install_mcr import *
from .fs_lib_check import *
from .fs_print_help import *
from .fs_run_from_mcr import *
from .fs_spmreg_glnxa64 import *
from .fs_temp_dir import *
from .fs_temp_file import *
from .fs_time import *
from .fs_tutorial_data import *
from .fs_update import *
from .fscalc import *
from .fscalc_fsl import *
from .fsdcmdecompress import *
from .fsfirst_fsl import *
from .fsl_5_0_2_xyztrans_sch import *
from .fsl_label2voxel import *
from .fsl_rigid_register import *
from .fsl_sub_mgh import *
from .fslmaths_fsl import *
from .fslorient_fsl import *
from .fslregister import *
from .fslswapdim_fsl import *
from .fspalm import *
from .fspython import *
from .fsr_coreg import *
from .fsr_getxopts import *
from .fsr_import import *
from .fsrealpath import *
from .fsvglrun import *
from .fvcompare import *
from .gauss_4dfp import *
from .gca_apply import *
from .gcainit import *
from .gcaprepone import *
from .gcatrain import *
from .gcatrainskull import *
from .gdcmconv_fs import *
from .gems_compute_atlas_probs import *
from .get_label_thickness import *
from .getfullpath import *
from .grad_unwarp import *
from .groupstats import *
from .groupstatsdiff import *
from .gtmseg import *
from .hiam_make_surfaces import *
from .hiam_make_template import *
from .hiam_register import *
from .histo_compute_joint_density import *
from .histo_register_block import *
from .histo_synthesize import *
from .ico_supersample import *
from .ifh2hdr import *
from .imgreg_4dfp import *
from .inflate_subject import *
from .inflate_subject3 import *
from .inflate_subject_lh import *
from .inflate_subject_new import *
from .inflate_subject_new_lh import *
from .inflate_subject_new_rh import *
from .inflate_subject_rh import *
from .inflate_subject_sc import *
from .irepifitvol import *
from .irepifitvol_glnx64 import *
from .is_lta import *
from .is_surface import *
from .isanalyze import *
from .isnifti import *
from .isolate_labels_csh import *
from .isolate_labels_keeporigval_csh import *
from .jkgcatrain import *
from .label2flat import *
from .label2patch import *
from .label_elderly_subject import *
from .label_subject import *
from .label_subject_flash import *
from .label_subject_mixed import *
from .labels_disjoint import *
from .labels_intersect import *
from .labels_union import *
from .list_otl_labels import *
from .listsubj import *
from .long_create_base_sigma import *
from .long_create_orig import *
from .long_mris_slopes import *
from .long_qdec_table import *
from .long_stats_combine import *
from .long_stats_slopes import *
from .long_stats_tps import *
from .long_submit_jobs import *
from .long_submit_postproc import *
from .longmc import *
from .lpcregister import *
from .lta_convert import *
from .lta_diff import *
from .make_average_subcort import *
from .make_average_subject import *
from .make_average_surface import *
from .make_average_volume import *
from .make_cortex_label import *
from .make_exvivo_filled import *
from .make_folding_atlas import *
from .make_hemi_mask import *
from .make_segvol_table import *
from .make_symmetric import *
from .make_upright import *
from .makevol import *
from .map_all_labels import *
from .map_all_labels_lh import *
from .map_central_sulcus import *
from .map_to_base import *
from .meanval import *
from .merge_stats_tables import *
from .mergeseg import *
from .mideface import *
from .minc2seqinfo import *
from .mkheadsurf import *
from .mkima_index_tcl import *
from .mkmnc_index_tcl import *
from .mksubjdirs import *
from .mksurfatlas import *
from .mkxsubjreg import *
from .mmppsp import *
from .mni152reg import *
from .morph_only_subject import *
from .morph_only_subject_lh import *
from .morph_only_subject_rh import *
from .morph_rgb_lh import *
from .morph_rgb_rh import *
from .morph_subject import *
from .morph_subject_lh import *
from .morph_subject_rh import *
from .morph_tables_lh import *
from .morph_tables_rh import *
from .mpr2mni305 import *
from .mri_3d_photo_recon import *
from .mri_add_new_tp import *
from .mri_add_xform_to_header import *
from .mri_align_long_csh import *
from .mri_and import *
from .mri_annotation2label import *
from .mri_aparc2aseg import *
from .mri_aparc2wmseg import *
from .mri_apply_bias import *
from .mri_average import *
from .mri_binarize import *
from .mri_brain_volume import *
from .mri_brainvol_stats import *
from .mri_ca_label import *
from .mri_ca_normalize import *
from .mri_ca_register import *
from .mri_ca_tissue_parms import *
from .mri_ca_train import *
from .mri_cal_renormalize_gca import *
from .mri_cc import *
from .mri_cnr import *
from .mri_compile_edits import *
from .mri_compute_bias import *
from .mri_compute_change_map import *
from .mri_compute_distances import *
from .mri_compute_layer_fractions import *
from .mri_compute_overlap import *
from .mri_compute_seg_overlap import *
from .mri_compute_volume_fractions import *
from .mri_compute_volume_intensities import *
from .mri_concat import *
from .mri_concatenate_gcam import *
from .mri_concatenate_lta import *
from .mri_convert import *
from .mri_copy_params import *
from .mri_copy_values import *
from .mri_cor2label import *
from .mri_coreg import *
from .mri_correct_segmentations import *
from .mri_create_t2combined import *
from .mri_create_tests import *
from .mri_cvs_check import *
from .mri_cvs_data_copy import *
from .mri_cvs_register import *
from .mri_dct_align import *
from .mri_dct_align_binary import *
from .mri_deface import *
from .mri_defacer import *
from .mri_diff import *
from .mri_dist_surf_label import *
from .mri_distance_transform import *
from .mri_easyreg import *
from .mri_easywarp import *
from .mri_edit_segmentation import *
from .mri_edit_segmentation_with_surfaces import *
from .mri_edit_wm_with_aseg import *
from .mri_em_register import *
from .mri_entowm_seg import *
from .mri_evaluate_morph import *
from .mri_extract import *
from .mri_extract_fcd_features import *
from .mri_extract_label import *
from .mri_extract_largest_cc import *
from .mri_exvivo_norm import *
from .mri_exvivo_strip import *
from .mri_fdr import *
from .mri_fieldsign import *
from .mri_fill import *
from .mri_fit_bias import *
from .mri_fslmat_to_lta import *
from .mri_func2sph import *
from .mri_funcvits import *
from .mri_fuse_intensity_images import *
from .mri_fuse_segmentations import *
from .mri_fwhm import *
from .mri_gca_ambiguous import *
from .mri_gcab_train import *
from .mri_gcut import *
from .mri_gdfglm import *
from .mri_glmfit import *
from .mri_glmfit_sim import *
from .mri_gradient_info import *
from .mri_gradunwarp import *
from .mri_gtmpvc import *
from .mri_gtmseg import *
from .mri_hausdorff_dist import *
from .mri_head import *
from .mri_hires_register import *
from .mri_histo_eq import *
from .mri_info import *
from .mri_jacobian import *
from .mri_joint_density import *
from .mri_label2label import *
from .mri_label2vol import *
from .mri_label_histo import *
from .mri_label_vals import *
from .mri_label_volume import *
from .mri_linear_align import *
from .mri_linear_align_binary import *
from .mri_linear_register import *
from .mri_log_likelihood import *
from .mri_long_normalize import *
from .mri_make_bem_surfaces import *
from .mri_make_uchar import *
from .mri_map_cpdat import *
from .mri_maps2csd import *
from .mri_mark_temporal_lobe import *
from .mri_mask import *
from .mri_matrix_multiply import *
from .mri_mc import *
from .mri_mcsim import *
from .mri_mergelabels import *
from .mri_mi import *
from .mri_modify import *
from .mri_morphology import *
from .mri_motion_correct import *
from .mri_motion_correct2 import *
from .mri_motion_correct_fsl import *
from .mri_ms_fitparms import *
from .mri_nl_align import *
from .mri_nl_align_binary import *
from .mri_nlfilter import *
from .mri_normalize import *
from .mri_normalize_tp2 import *
from .mri_nu_correct_mni import *
from .mri_or import *
from .mri_paint import *
from .mri_parse_sdcmdir import *
from .mri_path2label import *
from .mri_polv import *
from .mri_pretess import *
from .mri_probe_ima import *
from .mri_probedicom import *
from .mri_reduce import *
from .mri_refine_seg import *
from .mri_relabel_hypointensities import *
from .mri_relabel_nonwm_hypos import *
from .mri_remove_neck import *
from .mri_reorient_lr_csh import *
from .mri_rf_label import *
from .mri_rf_long_label import *
from .mri_rf_long_train import *
from .mri_rf_train import *
from .mri_ribbon import *
from .mri_rigid_register import *
from .mri_robust_register import *
from .mri_robust_template import *
from .mri_sbbr import *
from .mri_sclimbic_seg import *
from .mri_seg_diff import *
from .mri_seg_overlap import *
from .mri_segcentroids import *
from .mri_seghead import *
from .mri_segment import *
from .mri_segment_hypothalamic_subunits import *
from .mri_segment_thalamic_nuclei_dti_cnn import *
from .mri_segreg import *
from .mri_segstats import *
from .mri_sph2surf import *
from .mri_stats2seg import *
from .mri_stopmask import *
from .mri_strip_nonwhite import *
from .mri_strip_subject_info import *
from .mri_surf2surf import *
from .mri_surf2vol import *
from .mri_surf2volseg import *
from .mri_surfacemask import *
from .mri_surfcluster import *
from .mri_synthesize import *
from .mri_synthmorph import *
from .mri_synthseg import *
from .mri_synthsr import *
from .mri_synthsr_hyperfine import *
from .mri_synthstrip import *
from .mri_tessellate import *
from .mri_threshold import *
from .mri_topologycorrection import *
from .mri_train import *
from .mri_transform import *
from .mri_twoclass import *
from .mri_validate_skull_stripped import *
from .mri_vessel_segment import *
from .mri_vol2label import *
from .mri_vol2surf import *
from .mri_vol2vol import *
from .mri_volcluster import *
from .mri_voldiff import *
from .mri_volsynth import *
from .mri_warp_convert import *
from .mri_watershed import *
from .mri_wbc import *
from .mri_xvolavg import *
from .mri_z2p import *
from .mris2rgb import *
from .mris_aa_shrinkwrap import *
from .mris_add_template import *
from .mris_anatomical_stats import *
from .mris_annot_diff import *
from .mris_annot_to_segmentation import *
from .mris_apply_reg import *
from .mris_autodet_gwstats import *
from .mris_average_curvature import *
from .mris_ba_segment import *
from .mris_ca_deform import *
from .mris_ca_label import *
from .mris_ca_train import *
from .mris_calc import *
from .mris_compute_acorr import *
from .mris_compute_layer_intensities import *
from .mris_compute_lgi import *
from .mris_compute_overlap import *
from .mris_compute_parc_overlap import *
from .mris_compute_volume_fractions import *
from .mris_congeal import *
from .mris_convert import *
from .mris_copy_header import *
from .mris_curvature import *
from .mris_curvature2image import *
from .mris_curvature_stats import *
from .mris_defects_pointset import *
from .mris_deform import *
from .mris_diff import *
from .mris_distance_map import *
from .mris_distance_to_label import *
from .mris_distance_transform import *
from .mris_divide_parcellation import *
from .mris_entropy import *
from .mris_errors import *
from .mris_estimate_wm import *
from .mris_euler_number import *
from .mris_expand import *
from .mris_extract_main_component import *
from .mris_extract_patches import *
from .mris_extract_values import *
from .mris_exvivo_surfaces import *
from .mris_fill import *
from .mris_find_flat_regions import *
from .mris_fix_topology import *
from .mris_flatten import *
from .mris_fwhm import *
from .mris_gradient import *
from .mris_hausdorff_dist import *
from .mris_image2vtk import *
from .mris_inflate import *
from .mris_info import *
from .mris_init_global_tractography import *
from .mris_intensity_profile import *
from .mris_interpolate_warp import *
from .mris_jacobian import *
from .mris_label2annot import *
from .mris_label_area import *
from .mris_label_calc import *
from .mris_label_mode import *
from .mris_left_right_register import *
from .mris_make_average_surface import *
from .mris_make_face_parcellation import *
from .mris_make_surfaces import *
from .mris_make_template import *
from .mris_map_cuts import *
from .mris_mef_surfaces import *
from .mris_merge_parcellations import *
from .mris_mesh_subdivide import *
from .mris_morph_stats import *
from .mris_ms_refine import *
from .mris_multimodal import *
from .mris_multimodal_surface_placement import *
from .mris_multiscale_stats import *
from .mris_niters2fwhm import *
from .mris_nudge import *
from .mris_parcellate_connectivity import *
from .mris_place_surface import *
from .mris_pmake import *
from .mris_preproc import *
from .mris_profile_clustering import *
from .mris_refine_surfaces import *
from .mris_register import *
from .mris_register_label_map import *
from .mris_register_to_label import *
from .mris_register_to_volume import *
from .mris_remesh import *
from .mris_remove_intersection import *
from .mris_remove_negative_vertices import *
from .mris_remove_variance import *
from .mris_reposition_surface import *
from .mris_resample import *
from .mris_rescale import *
from .mris_reverse import *
from .mris_rf_label import *
from .mris_rf_train import *
from .mris_rotate import *
from .mris_sample_label import *
from .mris_sample_parc import *
from .mris_seg2annot import *
from .mris_segment import *
from .mris_segment_vals import *
from .mris_segmentation_stats import *
from .mris_shrinkwrap import *
from .mris_simulate_atrophy import *
from .mris_skeletonize import *
from .mris_smooth import *
from .mris_smooth_intracortical import *
from .mris_sphere import *
from .mris_spherical_average import *
from .mris_surf2vtk import *
from .mris_surface_stats import *
from .mris_surface_to_vol_distances import *
from .mris_talairach import *
from .mris_target_pos import *
from .mris_thickness import *
from .mris_thickness_comparison import *
from .mris_thickness_diff import *
from .mris_topo_fixer import *
from .mris_transform import *
from .mris_translate_annotation import *
from .mris_transmantle_dysplasia_paths import *
from .mris_volmask import *
from .mris_volmask_novtk import *
from .mris_volmask_vtk import *
from .mris_volsmooth import *
from .mris_volume import *
from .mris_warp import *
from .mris_watershed import *
from .mris_wm_volume import *
from .mrisp_paint import *
from .mrisp_write import *
from .ms_refine_subject import *
from .nmovie_qt import *
from .oct_register_mosaic import *
from .optseq2 import *
from .orient_las import *
from .parc_atlas_jackknife_test import *
from .pctsurfcon import *
from .plot_structure_stats_tcl import *
from .pointset2label import *
from .polyorder import *
from .post_recon_all import *
from .predict_v1_sh import *
from .print_unique_labels_csh import *
from .qatools_py import *
from .quantify_brainstem_structures_sh import *
from .quantify_hasubregions_sh import *
from .quantify_thalamic_nuclei_sh import *
from .rbbr import *
from .rca_base_init import *
from .rca_config import *
from .rca_config2csh import *
from .rca_fix_ento import *
from .rca_long_tp_init import *
from .rcbf_prep import *
from .recon_all import *
from .recon_all_clinical_sh import *
from .recon_all_exvivo import *
from .reconbatchjobs import *
from .reg2subject import *
from .reg_feat2anat import *
from .reg_mni305_2mm import *
from .regdat2xfm import *
from .register_child import *
from .register_csh import *
from .register_elderly_subject import *
from .register_subject import *
from .register_subject_flash import *
from .reinflate_subject import *
from .reinflate_subject_lh import *
from .reinflate_subject_rh import *
from .remove_talairach import *
from .renormalize_subject_keep_editting import *
from .renormalize_t1_subject import *
from .reregister_subject_mixed import *
from .rtview import *
from .run_mris_preproc import *
from .run_qdec_glm import *
from .run_samseg import *
from .run_samseg_long import *
from .run_segment_subfields_t1_longitudinal_sh import *
from .run_segment_subject_sh import *
from .run_segment_subject_t1_auto_estimate_alveus_ml_sh import *
from .run_segment_subject_t1_t2_auto_estimate_alveus_ml_sh import *
from .run_segment_subject_t2_auto_estimate_alveus_ml_sh import *
from .run_segment_thalamic_nuclei_sh import *
from .samseg import *
from .samseg2recon import *
from .samseg_long import *
from .samsegmesh2surf import *
from .sbtiv import *
from .seg2filled import *
from .seg2recon import *
from .segment_bs_sh import *
from .segment_ha_t1_long_sh import *
from .segment_ha_t1_sh import *
from .segment_ha_t2_sh import *
from .segment_monkey import *
from .segment_subfields_t1_longitudinal import *
from .segment_subject import *
from .segment_subject_notal import *
from .segment_subject_notal2 import *
from .segment_subject_old_skull_strip import *
from .segment_subject_sc import *
from .segment_subject_t1_auto_estimate_alveus_ml import *
from .segment_subject_t1_t2_auto_estimate_alveus_ml import *
from .segment_subject_t2_auto_estimate_alveus_ml import *
from .segment_subregions import *
from .segment_thalamic_nuclei import *
from .segment_thalamic_nuclei_sh import *
from .segpons import *
from .setlabelstat import *
from .sfa2fieldsign import *
from .slicedelay import *
from .slicetimer_fsl import *
from .sphere_subject import *
from .sphere_subject_lh import *
from .sphere_subject_rh import *
from .spline3_test import *
from .spm_t_to_b import *
from .spmregister import *
from .sratio import *
from .stat_normalize import *
from .stattablediff import *
from .stem2fname import *
from .surf2vol import *
from .surfreg import *
from .swi_preprocess import *
from .swi_process import *
from .t4img_4dfp import *
from .t4imgs_4dfp import *
from .table2map import *
from .tal_compare import *
from .tal_qc_azs import *
from .talairach import *
from .talairach2 import *
from .talairach_afd import *
from .talairach_avi import *
from .talairach_mgh import *
from .talsegprob import *
from .test_orientation_planes_from_parcellation import *
from .test_recon_all_csh import *
from .test_tutorials_sh import *
from .thickdiffmap import *
from .tkmedit import *
from .tkmeditfv import *
from .tkregister2 import *
from .tkregister2_cmdl import *
from .tkregisterfv import *
from .tksurfer import *
from .tksurferfv import *
from .trac_all import *
from .trac_paths import *
from .trac_preproc import *
from .tractstats2table import *
from .train_gcs_atlas import *
from .tridec import *
from .trk_tools import *
from .unpack_ima1_tcl import *
from .unpack_ima_tcl import *
from .unpack_mnc_tcl import *
from .unpackimadir import *
from .unpackimadir2 import *
from .unpackmincdir import *
from .unpacksdcmdir import *
from .update_needed import *
from .v_3dvolreg_afni import *
from .v_4dfptoanalyze import *
from .ventfix import *
from .vertexvol import *
from .vno_match_check import *
from .vol2segavg import *
from .vol2subfield import *
from .vol2symsurf import *
from .vsm_smooth import *
from .wfilemask import *
from .wm_anat_snr import *
from .wmedits2surf import *
from .wmsaseg import *
from .xcerebralseg import *
from .xcorr import *
from .xfmrot import *
from .xhemi_tal import *
from .xhemireg import *
from .xsanatreg import *
from .zero_lt_4dfp import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CCOPS_METADATA = Metadata(
    id="15f914d7513b2d71d9d54891eb8992cdb8593e4a.boutiques",
    name="ccops",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class CcopsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ccops(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output clustered ROI mask"""


def ccops(
    basename: str,
    infile: InputPathType | None = None,
    tract_dir: str | None = None,
    exclusion_mask: InputPathType | None = None,
    reorder_seedspace: bool = False,
    reorder_tractspace: bool = False,
    tract_reord: bool = False,
    connexity_constraint: float | None = 0,
    binarise_val: float | None = 0,
    matrix_power: float | None = 1,
    brain_mask: InputPathType | None = None,
    scheme: str | None = "spectral",
    nclusters: float | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> CcopsOutputs:
    """
    ccops - Clustering of Connectomes Using Probabilistic Tractography.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        basename: Output basename.
        infile: Input matrix.
        tract_dir: Tractography Results Directory.
        exclusion_mask: Exclusion mask (in tract space).
        reorder_seedspace: Do seedspace reordering (default no).
        reorder_tractspace: Do tractspace reordering (default no).
        tract_reord: Propagate seed reordering onto tract space.
        connexity_constraint: Add connexity constraint - value between 0 and 1\
            (0 is no constraint). Default is 0.
        binarise_val: Binarise at (default 0 - no binarisation).
        matrix_power: Power to raise the correlation matrix to (default 1).
        brain_mask: Brain mask used to output the clustered ROI mask (not\
            necessary if --dir set).
        scheme: Reordering algorithm. Can be either spectral (default), kmeans\
            or fuzzy.
        nclusters: Number of clusters to be used in kmeans or fuzzy.
        help_: Display this help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CcopsOutputs`).
    """
    if connexity_constraint is not None and not (0 <= connexity_constraint <= 1): 
        raise ValueError(f"'connexity_constraint' must be between 0 <= x <= 1 but was {connexity_constraint}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(CCOPS_METADATA)
    cargs = []
    cargs.append("ccops")
    cargs.extend([
        "--basename",
        basename
    ])
    if infile is not None:
        cargs.extend([
            "--in",
            execution.input_file(infile)
        ])
    if tract_dir is not None:
        cargs.extend([
            "--dir",
            tract_dir
        ])
    if exclusion_mask is not None:
        cargs.extend([
            "-x",
            execution.input_file(exclusion_mask)
        ])
    if reorder_seedspace:
        cargs.append("--r1")
    if reorder_tractspace:
        cargs.append("--r2")
    if tract_reord:
        cargs.append("--tractreord")
    if connexity_constraint is not None:
        cargs.extend([
            "--con",
            str(connexity_constraint)
        ])
    if binarise_val is not None:
        cargs.extend([
            "--bin",
            str(binarise_val)
        ])
    if matrix_power is not None:
        cargs.extend([
            "--power",
            str(matrix_power)
        ])
    if brain_mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(brain_mask)
        ])
    if scheme is not None:
        cargs.extend([
            "--scheme",
            scheme
        ])
    if nclusters is not None:
        cargs.extend([
            "--nclusters",
            str(nclusters)
        ])
    if help_:
        cargs.append("--help")
    ret = CcopsOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(basename + "_output.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CCOPS_METADATA",
    "CcopsOutputs",
    "ccops",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

N3_BIAS_FIELD_CORRECTION_METADATA = Metadata(
    id="12e6ca015aa736902ad4369af67b842768a91549.boutiques",
    name="N3BiasFieldCorrection",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class N3BiasFieldCorrectionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `n3_bias_field_correction(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_image: OutputPathType
    """The bias-corrected version of the input image."""
    bias_field: OutputPathType
    """The estimated bias field, if specified in the output."""


def n3_bias_field_correction(
    input_image: InputPathType,
    output: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    mask_image: InputPathType | None = None,
    rescale_intensities: typing.Literal[0, 1] | None = None,
    weight_image: InputPathType | None = None,
    shrink_factor: int | None = None,
    convergence: str | None = None,
    bspline_fitting: str | None = None,
    histogram_sharpening: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> N3BiasFieldCorrectionOutputs:
    """
    This N3 is a variant of the popular N3 (nonparametric nonuniform normalization)
    retrospective bias correction algorithm. Based on the assumption that the
    corruption of the low frequency bias field can be modeled as a convolution of
    the intensity histogram by a Gaussian, the basic algorithmic protocol is to
    iterate between deconvolving the intensity histogram by a Gaussian, remapping
    the intensities, and then spatially smoothing this result by a B-spline modeling
    of the bias field itself.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: A scalar image is expected as input for bias correction.\
            Since N3 log transforms the intensities, negative values or values\
            close to zero should be processed prior to correction.
        output: The bias-corrected version of the input image and optionally\
            the estimated bias field.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, N3 tries to infer the\
            dimensionality from the input image.
        mask_image: If a mask image is specified, the final bias correction is\
            only performed in the mask region. If a mask image is not specified,\
            the entire image region will be used as the mask region. Note: this\
            differs from the original N3 implementation.
        rescale_intensities: This option rescales the intensity range within\
            the user-specified mask to the original [min, max] range.
        weight_image: The weight image allows the user to perform a relative\
            weighting of specific voxels during the B-spline fitting.
        shrink_factor: Shrink factor to resample the input image. Commonly used\
            values are <= 4.
        convergence: Describes the convergence criteria with default value as\
            [50,0.0].
        bspline_fitting: Describes the parameters for B-Spline fitting.\
            Defaults are [splineDistance,4,3].
        histogram_sharpening: Describes histogram sharpening parameters;\
            defaults are [0.15,0.01,200].
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `N3BiasFieldCorrectionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(N3_BIAS_FIELD_CORRECTION_METADATA)
    cargs = []
    cargs.append("N3BiasFieldCorrection")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    cargs.extend([
        "--input-image",
        execution.input_file(input_image)
    ])
    if mask_image is not None:
        cargs.extend([
            "--mask-image",
            execution.input_file(mask_image)
        ])
    if rescale_intensities is not None:
        cargs.extend([
            "--rescale-intensities",
            str(rescale_intensities)
        ])
    if weight_image is not None:
        cargs.extend([
            "--weight-image",
            execution.input_file(weight_image)
        ])
    if shrink_factor is not None:
        cargs.extend([
            "--shrink-factor",
            str(shrink_factor)
        ])
    if convergence is not None:
        cargs.extend([
            "--convergence",
            convergence
        ])
    if bspline_fitting is not None:
        cargs.extend([
            "--bspline-fitting",
            bspline_fitting
        ])
    if histogram_sharpening is not None:
        cargs.extend([
            "--histogram-sharpening",
            histogram_sharpening
        ])
    cargs.extend([
        "--output",
        output
    ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    ret = N3BiasFieldCorrectionOutputs(
        root=execution.output_file("."),
        corrected_image=execution.output_file(output),
        bias_field=execution.output_file("[BIS_FIELD]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "N3BiasFieldCorrectionOutputs",
    "N3_BIAS_FIELD_CORRECTION_METADATA",
    "n3_bias_field_correction",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_STATS_SLOPES_METADATA = Metadata(
    id="c2f3a04515aabb1b936d652c2eb0e27439e032e8.boutiques",
    name="long_stats_slopes",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongStatsSlopesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_stats_slopes(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def long_stats_slopes(
    qdec_table: InputPathType,
    stats_file: InputPathType,
    measure: str,
    subjects_dir: str,
    do_avg: bool = False,
    do_rate: bool = False,
    do_pc1fit: bool = False,
    do_pc1: bool = False,
    do_spc: bool = False,
    do_stack: bool = False,
    resid: float | None = None,
    time_var: str | None = None,
    generic_time: bool = False,
    cross_sectional: bool = False,
    out_avg: str | None = None,
    out_rate: str | None = None,
    out_pc1fit: str | None = None,
    out_pc1: str | None = None,
    out_spc: str | None = None,
    out_resid: str | None = None,
    out_stack: str | None = None,
    stack_avg: str | None = None,
    stack_rate: str | None = None,
    stack_pc1fit: str | None = None,
    stack_pc1: str | None = None,
    stack_spc: str | None = None,
    stack_resid: str | None = None,
    runner: Runner | None = None,
) -> LongStatsSlopesOutputs:
    """
    Computes slopes of statistics in a longitudinal study for each subject from
    processed results, outputting to designated directories for further analysis.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec_table: QDEC table file specifying the subjects and time points.
        stats_file: The stats file, e.g. aseg.stats or lh.aparc.stats.
        measure: The stats measure (e.g. volume, thickness, mean, std).
        subjects_dir: Full path to FreeSurfer subjects directory.
        do_avg: Compute and output the temporal average.
        do_rate: Compute and output the rate.
        do_pc1fit: Compute and output the percent change with respect to tp1\
            from linear fit.
        do_pc1: Compute and output the percent change with respect to tp1.
        do_spc: Compute and output the symmetric percent change with respect to\
            temporal average.
        do_stack: Compute and output tables showing the time series (row per\
            time point).
        resid: Residual timepoint to export (pass 1 for tp1, etc., pass 0 for\
            average).
        time_var: Variable name for time column variable (e.g., age) in QDEC\
            table.
        generic_time: Time points are ordered in QDEC file; assume\
            time=1,2,3...
        cross_sectional: Use cross-sectional results (for testing only).
        out_avg: Filename to store temporal average in\
            <template>/stats/<OUT_AVG>.
        out_rate: Filename to store rate in <template>/stats/<OUT_RATE>.
        out_pc1fit: Filename to store percent change to tp1fit in\
            <template>/stats/<OUT_PC1FIT>.
        out_pc1: Filename to store percent change to tp1 in\
            <template>/stats/<OUT_PC1>.
        out_spc: Filename to store symmetric percent change in\
            <template>/stats/<OUT_SPC>.
        out_resid: Filename to store residual in <template>/stats/<OUT_RESID>.
        out_stack: Filename to store stacked measure file in\
            <template>/stats/<OUT_STACK>.
        stack_avg: Full filename to stack temporal average tables.
        stack_rate: Full filename to stack rate tables.
        stack_pc1fit: Full filename to stack percent change to tp1fit tables.
        stack_pc1: Full filename to stack percent change to tp1 tables.
        stack_spc: Full filename to stack symmetric percent change tables.
        stack_resid: Full filename to stack residual tables.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongStatsSlopesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_STATS_SLOPES_METADATA)
    cargs = []
    cargs.append("long_stats_slopes")
    cargs.extend([
        "--qdec",
        execution.input_file(qdec_table)
    ])
    cargs.extend([
        "--stats",
        execution.input_file(stats_file)
    ])
    cargs.extend([
        "--meas",
        measure
    ])
    cargs.extend([
        "--sd",
        subjects_dir
    ])
    if do_avg:
        cargs.append("--do-avg")
    if do_rate:
        cargs.append("--do-rate")
    if do_pc1fit:
        cargs.append("--do-pc1fit")
    if do_pc1:
        cargs.append("--do-pc1")
    if do_spc:
        cargs.append("--do-spc")
    if do_stack:
        cargs.append("--do-stack")
    if resid is not None:
        cargs.extend([
            "--resid",
            str(resid)
        ])
    if time_var is not None:
        cargs.extend([
            "--time",
            time_var
        ])
    if generic_time:
        cargs.append("--generic-time")
    if cross_sectional:
        cargs.append("--cross")
    if out_avg is not None:
        cargs.extend([
            "--out-avg",
            out_avg
        ])
    if out_rate is not None:
        cargs.extend([
            "--out-rate",
            out_rate
        ])
    if out_pc1fit is not None:
        cargs.extend([
            "--out-pc1fit",
            out_pc1fit
        ])
    if out_pc1 is not None:
        cargs.extend([
            "--out-pc1",
            out_pc1
        ])
    if out_spc is not None:
        cargs.extend([
            "--out-spc",
            out_spc
        ])
    if out_resid is not None:
        cargs.extend([
            "--out-resid",
            out_resid
        ])
    if out_stack is not None:
        cargs.extend([
            "--out-stack",
            out_stack
        ])
    if stack_avg is not None:
        cargs.extend([
            "--stack-avg",
            stack_avg
        ])
    if stack_rate is not None:
        cargs.extend([
            "--stack-rate",
            stack_rate
        ])
    if stack_pc1fit is not None:
        cargs.extend([
            "--stack-pc1fit",
            stack_pc1fit
        ])
    if stack_pc1 is not None:
        cargs.extend([
            "--stack-pc1",
            stack_pc1
        ])
    if stack_spc is not None:
        cargs.extend([
            "--stack-spc",
            stack_spc
        ])
    if stack_resid is not None:
        cargs.extend([
            "--stack-resid",
            stack_resid
        ])
    ret = LongStatsSlopesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_STATS_SLOPES_METADATA",
    "LongStatsSlopesOutputs",
    "long_stats_slopes",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MCSIM_METADATA = Metadata(
    id="c93d6e308a5345c3826d6a5f805dbcd44a658fe1.boutiques",
    name="mri_mcsim",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMcsimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mcsim(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    csd_output: OutputPathType
    """Output CSD files based on the base name"""
    done_output: OutputPathType | None
    """Done file created upon completion"""
    iteration_save: OutputPathType | None
    """Iteration save file"""
    log_output: OutputPathType | None
    """Log file generated during execution"""


def mri_mcsim(
    top_output_dir: str,
    base_name: str,
    surface: list[str],
    num_repetitions: float,
    fwhm_values: list[float] | None = None,
    fwhm_max: float | None = None,
    avg_vertex_area: bool = False,
    random_seed: float | None = None,
    label_file: InputPathType | None = None,
    mask_file: InputPathType | None = None,
    no_label: bool = False,
    no_save_mask: bool = False,
    surface_name: str | None = None,
    log_file: str | None = None,
    done_file: str | None = None,
    stop_file: str | None = None,
    save_file: str | None = None,
    save_iter: bool = False,
    subjects_dir: str | None = None,
    debug: bool = False,
    check_opts: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriMcsimOutputs:
    """
    Monte Carlo simulation tool for surface-based multiple comparisons.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        top_output_dir: Top output directory.
        base_name: Base name for CSD files.
        surface: Subject name and hemisphere for the surface (e.g., subjectname\
            lh).
        num_repetitions: Number of repetitions for the simulation.
        fwhm_values: Full Width at Half Maximum values for smoothing.
        fwhm_max: Maximum FWHM for simulation (default 30).
        avg_vertex_area: Report cluster area based on average vertex area.
        random_seed: Random seed value (default is based on Time of Day).
        label_file: Label file for masking (default is ?h.cortex.label).
        mask_file: Mask file instead of label.
        no_label: Do not use a label to mask.
        no_save_mask: Do not save mask to output.
        surface_name: Surface name (default is white).
        log_file: Log file for the output.
        done_file: Done file to create when finished.
        stop_file: Stop file (default is ourdir/mri_mcsim.stop).
        save_file: Save file (default is ourdir/mri_mcsim.save).
        save_iter: Save output after each iteration.
        subjects_dir: Subjects directory.
        debug: Turn on debugging.
        check_opts: Check options do not run.
        help_: Display help message.
        version: Display version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMcsimOutputs`).
    """
    if (len(surface) != 2): 
        raise ValueError(f"Length of 'surface' must be 2 but was {len(surface)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MCSIM_METADATA)
    cargs = []
    cargs.append("mri_mcsim")
    cargs.extend([
        "--o",
        top_output_dir
    ])
    cargs.extend([
        "--base",
        base_name
    ])
    cargs.extend([
        "--surface",
        *surface
    ])
    cargs.extend([
        "--nreps",
        str(num_repetitions)
    ])
    if fwhm_values is not None:
        cargs.extend([
            "--fwhm",
            *map(str, fwhm_values)
        ])
    if fwhm_max is not None:
        cargs.extend([
            "--fwhm-max",
            str(fwhm_max)
        ])
    if avg_vertex_area:
        cargs.append("--avgvtxarea")
    if random_seed is not None:
        cargs.extend([
            "--seed",
            str(random_seed)
        ])
    if label_file is not None:
        cargs.extend([
            "--label",
            execution.input_file(label_file)
        ])
    if mask_file is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_file)
        ])
    if no_label:
        cargs.append("--no-label")
    if no_save_mask:
        cargs.append("--no-save-mask")
    if surface_name is not None:
        cargs.extend([
            "--surfname",
            surface_name
        ])
    if log_file is not None:
        cargs.extend([
            "--log",
            log_file
        ])
    if done_file is not None:
        cargs.extend([
            "--done",
            done_file
        ])
    if stop_file is not None:
        cargs.extend([
            "--stop",
            stop_file
        ])
    if save_file is not None:
        cargs.extend([
            "--save",
            save_file
        ])
    if save_iter:
        cargs.append("--save-iter")
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if debug:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MriMcsimOutputs(
        root=execution.output_file("."),
        csd_output=execution.output_file(top_output_dir + "/" + base_name + ".csd"),
        done_output=execution.output_file(top_output_dir + "/done/" + done_file) if (done_file is not None) else None,
        iteration_save=execution.output_file(top_output_dir + "/" + save_file) if (save_file is not None) else None,
        log_output=execution.output_file(top_output_dir + "/log/" + log_file) if (log_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MCSIM_METADATA",
    "MriMcsimOutputs",
    "mri_mcsim",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BETA2SXA_METADATA = Metadata(
    id="715f661699d8a42e26b57d5896f55ec5edf8d5d2.boutiques",
    name="beta2sxa",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Beta2sxaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `beta2sxa(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sxa_output_file: OutputPathType
    """Output file for tkmedit or tksurfer visualization."""


def beta2sxa(
    beta_files: list[InputPathType],
    number_of_conditions: float,
    number_of_per_subjects: float,
    sxa_output: str | None = "h.beta",
    runner: Runner | None = None,
) -> Beta2sxaOutputs:
    """
    A script to create files for plotting in tkmedit or tksurfer based on tabular
    data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        beta_files: Input beta files, e.g., data.nii.
        number_of_conditions: Number of groups or conditions.
        number_of_per_subjects: Number of subjects per group.
        sxa_output: Output sxa file. Default is h.beta.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Beta2sxaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BETA2SXA_METADATA)
    cargs = []
    cargs.append("beta2sxa")
    cargs.extend([
        "--b",
        *[execution.input_file(f) for f in beta_files]
    ])
    cargs.extend([
        "--nc",
        str(number_of_conditions)
    ])
    cargs.extend([
        "--nper",
        str(number_of_per_subjects)
    ])
    if sxa_output is not None:
        cargs.extend([
            "--o",
            sxa_output
        ])
    ret = Beta2sxaOutputs(
        root=execution.output_file("."),
        sxa_output_file=execution.output_file("h.[MASK].nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BETA2SXA_METADATA",
    "Beta2sxaOutputs",
    "beta2sxa",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RCA_LONG_TP_INIT_METADATA = Metadata(
    id="e1c2f3934aa898b95f24c40fa06a81fee30ac0e8.boutiques",
    name="rca-long-tp-init",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RcaLongTpInitOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rca_long_tp_init(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rca_long_tp_init(
    timepoint: str,
    base: str,
    use_long_base_ctrl_vol: bool = False,
    hemisphere: typing.Literal["lh", "rh"] | None = None,
    expert_opts: InputPathType | None = None,
    subject: str | None = None,
    runner: Runner | None = None,
) -> RcaLongTpInitOutputs:
    """
    Initialize long timepoint subject for recon-all processing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        timepoint: Timepoint identifier.
        base: Base identifier.
        use_long_base_ctrl_vol: Use long base control volume.
        hemisphere: Specify the hemisphere (left or right).
        expert_opts: Expert options file.
        subject: Subject identifier for testing; put after -long.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RcaLongTpInitOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RCA_LONG_TP_INIT_METADATA)
    cargs = []
    cargs.append("rca-long-tp-init")
    cargs.extend([
        "-long",
        timepoint
    ])
    cargs.append(base)
    if use_long_base_ctrl_vol:
        cargs.append("-uselongbasectrlvol")
    if hemisphere is not None:
        cargs.extend([
            "-hemi",
            hemisphere
        ])
    if expert_opts is not None:
        cargs.extend([
            "-expert",
            execution.input_file(expert_opts)
        ])
    if subject is not None:
        cargs.extend([
            "-s",
            subject
        ])
    ret = RcaLongTpInitOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RCA_LONG_TP_INIT_METADATA",
    "RcaLongTpInitOutputs",
    "rca_long_tp_init",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TTOZ_METADATA = Metadata(
    id="9988bec3a64455c5b76a5e959148ef7d7d9455c4.boutiques",
    name="ttoz",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class TtozOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ttoz(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_zvol: OutputPathType | None
    """Output Z-statistic volume"""


def ttoz(
    varsfile: InputPathType,
    cbsfile: InputPathType,
    dof: int,
    outputvol: str | None = None,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> TtozOutputs:
    """
    Tool to convert a T-statistic image to a Z-statistic image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        varsfile: Input variables file.
        cbsfile: Input CBS file.
        dof: Degrees of freedom.
        outputvol: Output volume name (default is zstats).
        help_flag: Display help information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TtozOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TTOZ_METADATA)
    cargs = []
    cargs.append("ttoz")
    cargs.append(execution.input_file(varsfile))
    cargs.append(execution.input_file(cbsfile))
    cargs.append(str(dof))
    if outputvol is not None:
        cargs.extend([
            "-zout",
            outputvol
        ])
    if help_flag:
        cargs.append("-help")
    ret = TtozOutputs(
        root=execution.output_file("."),
        output_zvol=execution.output_file(outputvol + ".nii.gz") if (outputvol is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TTOZ_METADATA",
    "TtozOutputs",
    "ttoz",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_ENV_METADATA = Metadata(
    id="b177bf4393f72d4c785c1458de43a3ef880cfb18.boutiques",
    name="@AfniEnv",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniEnvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_env(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__afni_env(
    set_flag: list[str] | None = None,
    unset_flag: str | None = None,
    get_flag: str | None = None,
    help_flag: bool = False,
    help_web_flag_alias: bool = False,
    help_view_flag_alias: bool = False,
    all_opts_flag: bool = False,
    help_find_flag: str | None = None,
    runner: Runner | None = None,
) -> VAfniEnvOutputs:
    """
    Script to set or unset an AFNI environment variable in your .afnirc file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        set_flag: Set environment variable NAME to value VALUE.
        unset_flag: Unset environment variable NAME.
        get_flag: Get the value of environment variable NAME.
        help_flag: Display the help message for @AfniEnv script.
        help_web_flag_alias: Same as -h_web.
        help_view_flag_alias: Same as -h_view.
        all_opts_flag: List all of the options for this script.
        help_find_flag: Search for lines containing WORD in -help output.\
            Search is approximate.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniEnvOutputs`).
    """
    if set_flag is not None and (len(set_flag) != 2): 
        raise ValueError(f"Length of 'set_flag' must be 2 but was {len(set_flag)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_ENV_METADATA)
    cargs = []
    cargs.append("@AfniEnv")
    if set_flag is not None:
        cargs.extend([
            "-set",
            *set_flag
        ])
    if unset_flag is not None:
        cargs.extend([
            "-unset",
            unset_flag
        ])
    if get_flag is not None:
        cargs.extend([
            "-get",
            get_flag
        ])
    if help_flag:
        cargs.append("-help")
    if help_web_flag_alias:
        cargs.append("-hweb")
    if help_view_flag_alias:
        cargs.append("-hview")
    if all_opts_flag:
        cargs.append("-all_opts")
    if help_find_flag is not None:
        cargs.extend([
            "-h_find",
            help_find_flag
        ])
    ret = VAfniEnvOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniEnvOutputs",
    "V__AFNI_ENV_METADATA",
    "v__afni_env",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XCEREBRALSEG_METADATA = Metadata(
    id="14c3690bac7554084d7978a923e6d146bea56460.boutiques",
    name="xcerebralseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class XcerebralsegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xcerebralseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType
    """Output volume file for the whole head segmentation"""


def xcerebralseg(
    subject: str,
    output_volume: str | None = "apas+head.mgz",
    atlas: str | None = "/usr/local/freesurfer/average/aseg+spmhead+vermis+pons.ixi.gca",
    mergevol: str | None = "aparc+aseg.mgz",
    source_volume: str | None = "nu.mgz",
    no_stats: bool = False,
    seg1_name: str | None = None,
    no_pons: bool = False,
    no_vermis: bool = False,
    threads: float | None = None,
    runner: Runner | None = None,
) -> XcerebralsegOutputs:
    """
    Tool for labeling extracerebral structures including sulcal CSF, skull/bone,
    head soft tissue, and air inside the head, merged with aparc+aseg.mgz
    segmentation for a whole head segmentation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier (required).
        output_volume: Output volume file (default: apas+head.mgz).
        atlas: Atlas file path (default:\
            /usr/local/freesurfer/average/aseg+spmhead+vermis+pons.ixi.gca).
        mergevol: Merge with mergevol (default: aparc+aseg.mgz).
        source_volume: Source intensity volume (default: nu.mgz).
        no_stats: Do not run mri_segstats.
        seg1_name: Full-head segmentation name (usually computed with\
            mri_ca_label).
        no_pons: Exclude pons segmentation.
        no_vermis: Exclude vermis segmentation.
        threads: Set number of OPENMP threads.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XcerebralsegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XCEREBRALSEG_METADATA)
    cargs = []
    cargs.append("xcerebralseg")
    cargs.extend([
        "--s",
        subject
    ])
    if output_volume is not None:
        cargs.extend([
            "--o",
            output_volume
        ])
    if atlas is not None:
        cargs.extend([
            "--atlas",
            atlas
        ])
    if mergevol is not None:
        cargs.extend([
            "--m",
            mergevol
        ])
    if source_volume is not None:
        cargs.extend([
            "--srcvol",
            source_volume
        ])
    if no_stats:
        cargs.append("--no-stats")
    if seg1_name is not None:
        cargs.extend([
            "--seg1",
            seg1_name
        ])
    if no_pons:
        cargs.append("--no-pons")
    if no_vermis:
        cargs.append("--no-vermis")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    ret = XcerebralsegOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file("apas+head.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XCEREBRALSEG_METADATA",
    "XcerebralsegOutputs",
    "xcerebralseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_PATCH_METADATA = Metadata(
    id="1b9f54ccf622083c532013b3e22205e01ab00c46.boutiques",
    name="SurfPatch",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfPatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_patch(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outpatch_a: OutputPathType
    """Output patch for surface A"""
    outpatch_b: OutputPathType
    """Output patch for surface B"""
    out_stitched_surface: OutputPathType
    """Stitched surface file"""


def surf_patch(
    spec_file: InputPathType,
    surf_a: InputPathType,
    surf_b: InputPathType,
    nodefile: InputPathType,
    inode: float,
    ilabel: float,
    prefix: str,
    hits: float | None = None,
    masklabel: str | None = None,
    vol: bool = False,
    vol_only: bool = False,
    patch2surf: bool = False,
    coord_gain: float | None = None,
    check_bowtie: bool = False,
    fix_bowtie: bool = False,
    ok_bowtie: bool = False,
    adjust_contour: bool = False,
    do_not_adjust_contour: bool = False,
    stitched_surface: InputPathType | None = None,
    flip_orientation: bool = False,
    verbosity: float | None = None,
    runner: Runner | None = None,
) -> SurfPatchOutputs:
    """
    Creates a patch of surface formed by nodes in a nodefile and optionally
    calculates the volume between the same patch on two isotopic surfaces.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        spec_file: Spec file containing input surfaces.
        surf_a: Input surface A.
        surf_b: Input surface B.
        nodefile: File containing nodes defining the patch.
        inode: Index of the column containing the nodes.
        ilabel: Index of the column containing labels of the nodes in column\
            inode.
        prefix: Prefix of output patch.
        hits: Minimum number of nodes specified for a triangle to be made a\
            part of the patch (1 <= min_hits <= 3); default is 2.
        masklabel: Only nodes that are labeled with this label are considered\
            for the patch.
        vol: Calculate the volume formed by the patch on surf_A and surf_B.\
            Requires only two surfaces specified with surf_A and surf_B.
        vol_only: Only calculate the volume, don't write out patches.
        patch2surf: Turn surface patch into a surface where only nodes used in\
            forming the mesh are preserved.
        coord_gain: Multiply node coordinates by a gain. Useful for enlarging\
            tiny patches for easier viewing in SUMA.
        check_bowtie: Check if the patch has a section hanging by one node to\
            the rest of the mesh. Default when -vol or -vol_only are used.
        fix_bowtie: Modify patch to eliminate bowties.
        ok_bowtie: Do not check for, or fix bowties. Default when -vol* are not\
            used.
        adjust_contour: Shrink patch contours at nodes that were not in\
            nodefile.
        do_not_adjust_contour: Do not adjust contours. This is the default.
        stitched_surface: Write out the stitched surface used to calculate the\
            volume.
        flip_orientation: Change orientation of triangles before writing\
            surfaces.
        verbosity: Set verbosity level, 1 is the default.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfPatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_PATCH_METADATA)
    cargs = []
    cargs.append("SurfPatch")
    cargs.append(execution.input_file(spec_file))
    cargs.extend([
        "-surf_A",
        execution.input_file(surf_a)
    ])
    cargs.extend([
        "-surf_B",
        execution.input_file(surf_b)
    ])
    cargs.extend([
        "-input",
        execution.input_file(nodefile)
    ])
    cargs.append(str(inode))
    cargs.append(str(ilabel))
    cargs.extend([
        "-prefix",
        prefix
    ])
    if hits is not None:
        cargs.extend([
            "-hits",
            str(hits)
        ])
    if masklabel is not None:
        cargs.extend([
            "-masklabel",
            masklabel
        ])
    if vol:
        cargs.append("-vol")
    if vol_only:
        cargs.append("-vol_only")
    if patch2surf:
        cargs.append("-patch2surf")
    if coord_gain is not None:
        cargs.extend([
            "-coord_gain",
            str(coord_gain)
        ])
    if check_bowtie:
        cargs.append("-check_bowtie")
    if fix_bowtie:
        cargs.append("-fix_bowtie")
    if ok_bowtie:
        cargs.append("-ok_bowtie")
    if adjust_contour:
        cargs.append("-adjust_contour")
    if do_not_adjust_contour:
        cargs.append("-do-not-adjust_contour")
    if stitched_surface is not None:
        cargs.extend([
            "-stitched_surface",
            execution.input_file(stitched_surface)
        ])
    if flip_orientation:
        cargs.append("-flip_orientation")
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = SurfPatchOutputs(
        root=execution.output_file("."),
        outpatch_a=execution.output_file(prefix + "_A"),
        outpatch_b=execution.output_file(prefix + "_B"),
        out_stitched_surface=execution.output_file(prefix + "_stitched"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_PATCH_METADATA",
    "SurfPatchOutputs",
    "surf_patch",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_JACOBIAN_METADATA = Metadata(
    id="261fa5191d385d242b16ec1808b1a5ac51b44bc2.boutiques",
    name="mri_jacobian",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriJacobianOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_jacobian(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_vol: OutputPathType
    """Resulting volume file after Jacobian computation"""


def mri_jacobian(
    morph_file: InputPathType,
    template_vol: InputPathType,
    output_vol: str,
    atlas_coord: bool = False,
    write_area_vols: bool = False,
    log_jacobian: bool = False,
    smooth_sigma: float | None = None,
    zero_mean_log: bool = False,
    tm3d: bool = False,
    help2: bool = False,
    dt: bool = False,
    debug_voxel: list[float] | None = None,
    remove: bool = False,
    runner: Runner | None = None,
) -> MriJacobianOutputs:
    """
    Compute the Jacobian of a morph with FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        morph_file: 3D morph input file.
        template_vol: Template volume file.
        output_vol: Output volume file.
        atlas_coord: Output is written in atlas coordinate system.
        write_area_vols: Writing area volumes.
        log_jacobian: Taking log of Jacobian values before saving.
        smooth_sigma: Smoothing Jacobian volume with sigma.
        zero_mean_log: Make log Jacobian zero mean.
        tm3d: The input morph (m3z) originated from tm3d (mri_cvs_register).
        help2: Writing out help.
        dt: DT option (description not provided in help text).
        debug_voxel: Debug voxel with specified Gx, Gy, Gz coordinates.
        remove: Remove option (description not provided in help text).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriJacobianOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_JACOBIAN_METADATA)
    cargs = []
    cargs.append("mri_jacobian")
    cargs.append(execution.input_file(morph_file))
    cargs.append(execution.input_file(template_vol))
    cargs.append(output_vol)
    if atlas_coord:
        cargs.append("-a")
    if write_area_vols:
        cargs.append("-w")
    if log_jacobian:
        cargs.append("-l")
    if smooth_sigma is not None:
        cargs.extend([
            "-s",
            str(smooth_sigma)
        ])
    if zero_mean_log:
        cargs.append("-z")
    if tm3d:
        cargs.append("-tm3d")
    if help2:
        cargs.append("-u")
    if dt:
        cargs.append("-dt")
    if debug_voxel is not None:
        cargs.extend([
            "-debug_voxel",
            *map(str, debug_voxel)
        ])
    if remove:
        cargs.append("-remove")
    ret = MriJacobianOutputs(
        root=execution.output_file("."),
        result_vol=execution.output_file(output_vol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_JACOBIAN_METADATA",
    "MriJacobianOutputs",
    "mri_jacobian",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_ADD_XFORM_TO_HEADER_METADATA = Metadata(
    id="a352e8c6ada4a640929cf21a7797106f093df774.boutiques",
    name="mri_add_xform_to_header",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAddXformToHeaderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_add_xform_to_header(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType
    """Volume output with added transformation."""


def mri_add_xform_to_header(
    xfm_file: InputPathType,
    input_volume: InputPathType,
    output_volume: str,
    verbose: bool = False,
    copy_name: bool = False,
    runner: Runner | None = None,
) -> MriAddXformToHeaderOutputs:
    """
    Program to add specified transformation to the volume header.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        xfm_file: Transformation file to be added to the volume header.
        input_volume: Input volume to which the transformation is added.
        output_volume: Output volume with the transformation included.
        verbose: Enable verbose output for more detailed logging.
        copy_name: Copy the name of the xfm file without loading it.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAddXformToHeaderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_ADD_XFORM_TO_HEADER_METADATA)
    cargs = []
    cargs.append("mri_add_xform_to_header")
    cargs.append(execution.input_file(xfm_file))
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_volume)
    if verbose:
        cargs.append("-v")
    if copy_name:
        cargs.append("-c")
    ret = MriAddXformToHeaderOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_ADD_XFORM_TO_HEADER_METADATA",
    "MriAddXformToHeaderOutputs",
    "mri_add_xform_to_header",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DWIGRADCHECK_METADATA = Metadata(
    id="bb74671ccd6fa59a51829fa34812108f525873cb.boutiques",
    name="dwigradcheck",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class DwigradcheckFslgrad:
    """
    Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used.
    """
    bvecs: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    bvals: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fslgrad")
        cargs.append(execution.input_file(self.bvecs))
        cargs.append(execution.input_file(self.bvals))
        return cargs


class DwigradcheckExportGradFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `DwigradcheckExportGradFsl | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    bvecs_path: OutputPathType
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""
    bvals_path: OutputPathType
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""


@dataclasses.dataclass
class DwigradcheckExportGradFsl:
    """
    export the diffusion-weighted gradient table to files in FSL (bvecs / bvals)
    format.
    """
    bvecs_path: str
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""
    bvals_path: str
    """export the diffusion-weighted gradient table to files in FSL (bvecs /
    bvals) format"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-export_grad_fsl")
        cargs.append(self.bvecs_path)
        cargs.append(self.bvals_path)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> DwigradcheckExportGradFslOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `DwigradcheckExportGradFslOutputs`).
        """
        ret = DwigradcheckExportGradFslOutputs(
            root=execution.output_file("."),
            bvecs_path=execution.output_file(self.bvecs_path),
            bvals_path=execution.output_file(self.bvals_path),
        )
        return ret


class DwigradcheckOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dwigradcheck(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    export_grad_mrtrix: OutputPathType | None
    """export the diffusion-weighted gradient table to file in MRtrix format """
    export_grad_fsl: OutputPathType | None
    """export the diffusion-weighted gradient table to file in FSL format """
    export_grad_fsl_: DwigradcheckExportGradFslOutputs | None
    """Outputs from `DwigradcheckExportGradFsl`."""


def dwigradcheck(
    input_image: InputPathType,
    grad: InputPathType | None = None,
    fslgrad: DwigradcheckFslgrad | None = None,
    mask_image: InputPathType | None = None,
    number: int | None = None,
    export_grad_mrtrix: str | None = None,
    export_grad_fsl: DwigradcheckExportGradFsl | None = None,
    nocleanup: bool = False,
    scratch_dir: InputPathType | None = None,
    continue_scratch_dir: list[InputPathType] | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: float | None = None,
    config: list[str] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DwigradcheckOutputs:
    """
    Check the orientation of the diffusion gradient table.
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        input_image: The input DWI series to be checked.
        grad: Provide the diffusion gradient table in MRtrix format.
        fslgrad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in FSL bvecs/bvals format files. If a diffusion gradient\
            scheme is present in the input image header, the data provided with\
            this option will be instead used.
        mask_image: Provide a brain mask image.
        number: Set the number of tracks to generate for each test.
        export_grad_mrtrix: export the diffusion-weighted gradient table to\
            file in MRtrix format.
        export_grad_fsl: export the diffusion-weighted gradient table to files\
            in FSL (bvecs / bvals) format.
        nocleanup: Do not delete intermediate files during script execution,\
            and do not delete scratch directory at script completion.
        scratch_dir: Manually specify the path in which to generate the scratch\
            directory.
        continue_scratch_dir: Continue the script from a previous execution;\
            must provide the scratch directory path.
        info: Display information messages.
        quiet: Do not display information messages or progress status.
        debug: Display debugging messages.
        force: Force overwrite of output files.
        nthreads: Use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: Temporarily set the value of an MRtrix config file entry.
        help_: Display help information and exit.
        version: Display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DwigradcheckOutputs`).
    """
    if continue_scratch_dir is not None and (len(continue_scratch_dir) != 2): 
        raise ValueError(f"Length of 'continue_scratch_dir' must be 2 but was {len(continue_scratch_dir)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(DWIGRADCHECK_METADATA)
    cargs = []
    cargs.append("dwigradcheck")
    cargs.append(execution.input_file(input_image))
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if fslgrad is not None:
        cargs.extend(fslgrad.run(execution))
    if mask_image is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_image)
        ])
    if number is not None:
        cargs.extend([
            "-number",
            str(number)
        ])
    if export_grad_mrtrix is not None:
        cargs.extend([
            "-export_grad_mrtrix",
            export_grad_mrtrix
        ])
    if export_grad_fsl is not None:
        cargs.extend(export_grad_fsl.run(execution))
    if nocleanup:
        cargs.append("-nocleanup")
    if scratch_dir is not None:
        cargs.extend([
            "-scratch",
            execution.input_file(scratch_dir)
        ])
    if continue_scratch_dir is not None:
        cargs.extend([
            "-continue",
            *[execution.input_file(f) for f in continue_scratch_dir]
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([
            "-config",
            *config
        ])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    ret = DwigradcheckOutputs(
        root=execution.output_file("."),
        export_grad_mrtrix=execution.output_file(export_grad_mrtrix) if (export_grad_mrtrix is not None) else None,
        export_grad_fsl=execution.output_file(export_grad_mrtrix) if (export_grad_mrtrix is not None) else None,
        export_grad_fsl_=export_grad_fsl.outputs(execution) if export_grad_fsl else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DWIGRADCHECK_METADATA",
    "DwigradcheckExportGradFsl",
    "DwigradcheckExportGradFslOutputs",
    "DwigradcheckFslgrad",
    "DwigradcheckOutputs",
    "dwigradcheck",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_COLOR_MAP_METADATA = Metadata(
    id="20feab346cace5f8666142aaf08be813c7020806.boutiques",
    name="MakeColorMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MakeColorMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_color_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    afni_hex_output_prefix: OutputPathType | None
    """Prefix for individual color values in AFNI Hex format."""
    palette_file_output: OutputPathType
    """Example palette file output."""


def make_color_map(
    fiducials_ncol: InputPathType | None = None,
    fiducials: InputPathType | None = None,
    num_colors: float | None = None,
    std_mapname: str | None = None,
    palette_file: InputPathType | None = None,
    cmap_name: str | None = None,
    fscolut_labels: list[float] | None = None,
    fscolut_file: InputPathType | None = None,
    afni_hex: str | None = None,
    afni_hex_complete: str | None = None,
    suma_colormap: str | None = None,
    user_colut_file: InputPathType | None = None,
    sdset: InputPathType | None = None,
    sdset_prefix: str | None = None,
    flipupdown: bool = False,
    skip_last: bool = False,
    show_fscolut: bool = False,
    help_flag: bool = False,
    help_full_flag: bool = False,
    flip_map_updside_down: bool = False,
    runner: Runner | None = None,
) -> MakeColorMapOutputs:
    """
    Utility for creating and modifying colormaps with various formats and fiducial
    points.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        fiducials_ncol: Fiducial colors and their indices in the color map are\
            listed in file Fiducials_Ncol.
        fiducials: Fiducial colors are listed in an ascii file Fiducials.
        num_colors: Total number of colors in the color map.
        std_mapname: Returns one of SUMA's standard colormaps.
        palette_file: Specify the palette file for colormap.
        cmap_name: Specify the colormap name.
        fscolut_labels: Get AFNI/SUMA colormaps of FreeSurfer colors indexed\
            between lbl0 and lbl1.
        fscolut_file: Use color LUT file FS_COL_LUT.
        afni_hex: Afni Hex format. Use this option if you want a color map\
            formatted to fit in AFNI's .afnirc file.
        afni_hex_complete: Afni Hex format, ready to go into pbardefs.h.
        suma_colormap: Write colormap in SUMA's format.
        user_colut_file: Provide a user's own color lookup file.
        sdset: Add colormap to surface-based dataset DSET, making it a labeled\
            dataset.
        sdset_prefix: Prefix of dset for writing labeled version of DSET.
        flipupdown: Flip the map upside down.
        skip_last: If used, the last color in the Fiducial list is omitted.
        show_fscolut: Show all of the FreeSurfer LUT.
        help_flag: Displays the help message.
        help_full_flag: Displays the help message.
        flip_map_updside_down: Flip the map upside down.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeColorMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_COLOR_MAP_METADATA)
    cargs = []
    cargs.append("MakeColorMap")
    if fiducials_ncol is not None:
        cargs.extend([
            "-fn",
            execution.input_file(fiducials_ncol)
        ])
    if fiducials is not None:
        cargs.extend([
            "-f",
            execution.input_file(fiducials)
        ])
    if num_colors is not None:
        cargs.extend([
            "-nc",
            str(num_colors)
        ])
    if std_mapname is not None:
        cargs.extend([
            "-std",
            std_mapname
        ])
    if palette_file is not None:
        cargs.extend([
            "-cmapdb",
            execution.input_file(palette_file)
        ])
    if cmap_name is not None:
        cargs.extend([
            "-cmap",
            cmap_name
        ])
    if fscolut_labels is not None:
        cargs.extend([
            "-fscolut",
            *map(str, fscolut_labels)
        ])
    if fscolut_file is not None:
        cargs.extend([
            "-fscolutfile",
            execution.input_file(fscolut_file)
        ])
    if afni_hex is not None:
        cargs.extend([
            "-ah",
            afni_hex
        ])
    if afni_hex_complete is not None:
        cargs.extend([
            "-ahc",
            afni_hex_complete
        ])
    if suma_colormap is not None:
        cargs.extend([
            "-suma_cmap",
            suma_colormap
        ])
    if user_colut_file is not None:
        cargs.extend([
            "-usercolutfile",
            execution.input_file(user_colut_file)
        ])
    if sdset is not None:
        cargs.extend([
            "-sdset",
            execution.input_file(sdset)
        ])
    if sdset_prefix is not None:
        cargs.extend([
            "-sdset_prefix",
            sdset_prefix
        ])
    if flipupdown:
        cargs.append("-flipud")
    if skip_last:
        cargs.append("-sl")
    if show_fscolut:
        cargs.append("-show_fscolut")
    if help_flag:
        cargs.append("-h")
    if help_full_flag:
        cargs.append("-help")
    if flip_map_updside_down:
        cargs.append("-flipud")
    ret = MakeColorMapOutputs(
        root=execution.output_file("."),
        afni_hex_output_prefix=execution.output_file(afni_hex + "_01") if (afni_hex is not None) else None,
        palette_file_output=execution.output_file("TestPalette.pal"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_COLOR_MAP_METADATA",
    "MakeColorMapOutputs",
    "make_color_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BUILD_DESIKAN_KILLIANY_GCS_CSH_METADATA = Metadata(
    id="533d45cdbfae4bc58aadf050a7461db1dc6a6914.boutiques",
    name="build_desikan_killiany_gcs.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BuildDesikanKillianyGcsCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `build_desikan_killiany_gcs_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def build_desikan_killiany_gcs_csh(
    hemi: str,
    runner: Runner | None = None,
) -> BuildDesikanKillianyGcsCshOutputs:
    """
    Tool to build Desikan-Killiany cortical parcellation in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere designation for the operation. Should be 'rh' for\
            right hemisphere or 'lh' for left hemisphere.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BuildDesikanKillianyGcsCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BUILD_DESIKAN_KILLIANY_GCS_CSH_METADATA)
    cargs = []
    cargs.append("build_desikan_killiany_gcs.csh")
    cargs.append(hemi)
    ret = BuildDesikanKillianyGcsCshOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BUILD_DESIKAN_KILLIANY_GCS_CSH_METADATA",
    "BuildDesikanKillianyGcsCshOutputs",
    "build_desikan_killiany_gcs_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGPONS_METADATA = Metadata(
    id="4b38e194fdd9fe1d16fc15d6ac746b2dffa56e0f.boutiques",
    name="segpons",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegponsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segpons(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    pons_output: OutputPathType
    """Output pons segmentation file."""


def segpons(
    subject: str,
    aseg: bool = False,
    apas: bool = False,
    seg: InputPathType | None = None,
    no_refine: bool = False,
    pons152_mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> SegponsOutputs:
    """
    Approximate segmentation of pons using MNI152 space registration.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        aseg: Use and refine aseg (default, output will be aseg+pons.mgz).
        apas: Use aparc+aseg.mgz (output will be apas+pons.mgz).
        seg: Specify your own segmentation file.
        no_refine: Do not refine when using aseg.
        pons152_mask: Mask of pons in MNI152 space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegponsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGPONS_METADATA)
    cargs = []
    cargs.append("segpons")
    cargs.extend([
        "-s",
        "-" + subject
    ])
    if aseg:
        cargs.append("--aseg")
    if apas:
        cargs.append("--apas")
    if seg is not None:
        cargs.extend([
            "--seg",
            execution.input_file(seg)
        ])
    if no_refine:
        cargs.append("--no-refine")
    if pons152_mask is not None:
        cargs.extend([
            "--pons152",
            execution.input_file(pons152_mask)
        ])
    ret = SegponsOutputs(
        root=execution.output_file("."),
        pons_output=execution.output_file(subject + "+pons.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGPONS_METADATA",
    "SegponsOutputs",
    "segpons",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DIFF_TREE_METADATA = Metadata(
    id="11a09e53b48435f523465bdd52c5dc27b5e1cb04.boutiques",
    name="@diff.tree",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDiffTreeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__diff_tree(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__diff_tree(
    new_dir: str,
    old_dir: str,
    diff_opts: str | None = None,
    ignore_append: str | None = None,
    ia: str | None = None,
    ignore_list: str | None = None,
    il: str | None = None,
    ignore_missing: bool = False,
    no_diffs: bool = False,
    quiet: bool = False,
    save: bool = False,
    show: bool = False,
    show_list_comp: bool = False,
    skip_data: bool = False,
    verb: str | None = None,
    diff_prog: str | None = None,
    xxdiff: bool = False,
    x_option: bool = False,
    runner: Runner | None = None,
) -> VDiffTreeOutputs:
    """
    Show file differences between 2 directories.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        new_dir: New directory to compare.
        old_dir: Old directory to compare.
        diff_opts: Apply OPTS as options in diff commands.
        ignore_append: Append to ignore_list (list in quotes).
        ia: Short for -ignore_append.
        ignore_list: Create new ignore_list (list in quotes).
        il: Short for -ignore_list.
        ignore_missing: Only compare overlapping files, if different files,\
            fail.
        no_diffs: Only compare existence of files.
        quiet: Only list files with diffs.
        save: Save actual file differences (txt and pdf).
        show: Show actual file differences.
        show_list_comp: Show any pairwise differences in file lists (terminate\
            after showing comparison).
        skip_data: Skip binary diff of select data files (.BRIK, .dcm,\
            .BRIK.gz).
        verb: Set verbosity level (0,1,2) (default 1).
        diff_prog: Use PROG to show diffs (e.g. xxdiff, meld).
        xxdiff: Use xxdiff to show diffs.
        x_option: Implies -xxdiff -ignore_missing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDiffTreeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DIFF_TREE_METADATA)
    cargs = []
    cargs.append("@diff.tree")
    cargs.append(new_dir)
    cargs.append(old_dir)
    if diff_opts is not None:
        cargs.extend([
            "-diff_opts",
            diff_opts
        ])
    if ignore_append is not None:
        cargs.extend([
            "-ignore_append",
            ignore_append
        ])
    if ia is not None:
        cargs.extend([
            "-ia",
            ia
        ])
    if ignore_list is not None:
        cargs.extend([
            "-ignore_list",
            ignore_list
        ])
    if il is not None:
        cargs.extend([
            "-il",
            il
        ])
    if ignore_missing:
        cargs.append("-ignore_missing")
    if no_diffs:
        cargs.append("-no_diffs")
    if quiet:
        cargs.append("-quiet")
    if save:
        cargs.append("-save")
    if show:
        cargs.append("-show")
    if show_list_comp:
        cargs.append("-show_list_comp")
    if skip_data:
        cargs.append("-skip_data")
    if verb is not None:
        cargs.extend([
            "-verb",
            verb
        ])
    if diff_prog is not None:
        cargs.extend([
            "-diff_prog",
            diff_prog
        ])
    if xxdiff:
        cargs.append("-xxdiff")
    if x_option:
        cargs.append("-X")
    ret = VDiffTreeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDiffTreeOutputs",
    "V__DIFF_TREE_METADATA",
    "v__diff_tree",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MULTIMODAL_SURFACE_PLACEMENT_METADATA = Metadata(
    id="0cfb3e00bbd6f85769e241237d86c23951a65897.boutiques",
    name="mris_multimodal_surface_placement",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMultimodalSurfacePlacementOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_multimodal_surface_placement(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_multimodal_surface_placement(
    input_surface: InputPathType,
    output_surface: InputPathType,
    sphere_surface: InputPathType,
    normals: str,
    values_: str,
    step_size: float,
    number_of_steps: float,
    gradient_sigma: float,
    aseg_aparc: InputPathType,
    white_surface: InputPathType,
    prob_of_csf: float,
    t1_image: InputPathType,
    t2_image: InputPathType,
    flair_image: InputPathType,
    debug_vertex: float | None = None,
    min_max: bool = False,
    runner: Runner | None = None,
) -> MrisMultimodalSurfacePlacementOutputs:
    """
    FreeSurfer command for multimodal surface placement.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        output_surface: Output surface file.
        sphere_surface: Sphere surface file.
        normals: Normals file in VTK format.
        values_: Values file in VTK format.
        step_size: Step size.
        number_of_steps: Number of steps.
        gradient_sigma: Gradient sigma value.
        aseg_aparc: ASEG APARC image file.
        white_surface: White surface file.
        prob_of_csf: Probability of CSF.
        t1_image: T1-weighted image file.
        t2_image: T2-weighted image file.
        flair_image: FLAIR image file.
        debug_vertex: Debug vertex index.
        min_max: Toggle between min or max operation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMultimodalSurfacePlacementOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MULTIMODAL_SURFACE_PLACEMENT_METADATA)
    cargs = []
    cargs.append("mris_multimodal_surface_placement")
    cargs.extend([
        "-i",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output_surface)
    ])
    cargs.extend([
        "-b",
        execution.input_file(sphere_surface)
    ])
    cargs.extend([
        "-n",
        normals
    ])
    cargs.extend([
        "-v",
        values_
    ])
    if debug_vertex is not None:
        cargs.extend([
            "-d",
            str(debug_vertex)
        ])
    cargs.extend([
        "-s",
        str(step_size)
    ])
    cargs.extend([
        "-k",
        str(number_of_steps)
    ])
    cargs.extend([
        "-g",
        str(gradient_sigma)
    ])
    cargs.extend([
        "-a",
        execution.input_file(aseg_aparc)
    ])
    cargs.extend([
        "-w",
        execution.input_file(white_surface)
    ])
    cargs.extend([
        "-p",
        str(prob_of_csf)
    ])
    cargs.extend([
        "-t1",
        execution.input_file(t1_image)
    ])
    cargs.extend([
        "-t2",
        execution.input_file(t2_image)
    ])
    cargs.extend([
        "-flair",
        execution.input_file(flair_image)
    ])
    if min_max:
        cargs.append("-min/max")
    ret = MrisMultimodalSurfacePlacementOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MULTIMODAL_SURFACE_PLACEMENT_METADATA",
    "MrisMultimodalSurfacePlacementOutputs",
    "mris_multimodal_surface_placement",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GPS_METADATA = Metadata(
    id="b6e9756556d50c5c524e3645c380d3d12a887881.boutiques",
    name="gps",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class GpsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gps(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output file with generated directions"""


def gps(
    ndir: float,
    optws: bool = False,
    output: str | None = "bvecs#.txt",
    ranseed: float | None = None,
    init: InputPathType | None = None,
    report: bool = False,
    verbose: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> GpsOutputs:
    """
    Generate set of diffusion gradient directions.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        ndir: Number of directions.
        optws: Perform additional optimisation on the whole sphere (needed for\
            eddy).
        output: Name of output file (default: bvecs#.txt).
        ranseed: Seed random generator with supplied number.
        init: File with bvecs to use as initialisation.
        report: Report coulomb forces for initial configuration.
        verbose: Switch on diagnostic messages.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GpsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GPS_METADATA)
    cargs = []
    cargs.append("gps")
    cargs.extend([
        "--ndir",
        str(ndir)
    ])
    if optws:
        cargs.append("--optws")
    if output is not None:
        cargs.extend([
            "--out",
            output
        ])
    if ranseed is not None:
        cargs.extend([
            "--ranseed",
            str(ranseed)
        ])
    if init is not None:
        cargs.extend([
            "--init",
            execution.input_file(init)
        ])
    if report:
        cargs.append("--report")
    if verbose:
        cargs.append("-v,--verbose")
    if help_:
        cargs.append("-h,--help")
    ret = GpsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output) if (output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GPS_METADATA",
    "GpsOutputs",
    "gps",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_CREATE_BASE_SIGMA_METADATA = Metadata(
    id="359af0d6b57993950b3f756ef93dd6df37402a88.boutiques",
    name="long_create_base_sigma",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongCreateBaseSigmaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_create_base_sigma(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def long_create_base_sigma(
    base_id: str,
    sigma: int,
    runner: Runner | None = None,
) -> LongCreateBaseSigmaOutputs:
    """
    Performs a joint normalization and atlas renormalization at a specific sigma
    smoothing level. This is usually done as part of the base stream but can be
    performed to add files for a different sigma level to an existing base.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        base_id: Subject ID of the base.
        sigma: Integer value of sigma smoothing (usually 2..6).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongCreateBaseSigmaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_CREATE_BASE_SIGMA_METADATA)
    cargs = []
    cargs.append("long_create_base_sigma")
    cargs.append(base_id)
    cargs.append(str(sigma))
    ret = LongCreateBaseSigmaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_CREATE_BASE_SIGMA_METADATA",
    "LongCreateBaseSigmaOutputs",
    "long_create_base_sigma",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BEDPOSTX_METADATA = Metadata(
    id="8d827db247c8140fd0612e8c4f7db7d170cfc43e.boutiques",
    name="bedpostx",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class BedpostxOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bedpostx(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    xfms_output: OutputPathType
    """Output transformations."""
    diff_slices_output: OutputPathType
    """Output diffusion slices."""


def bedpostx(
    subject_dir: str,
    num_fibres: float | None = 3,
    ard_weight: float | None = 1,
    burnin: float | None = 1000,
    num_jumps: float | None = 1250,
    sample_every: float | None = 25,
    model_type: float | None = 2,
    grad_nonlinear: bool = False,
    runner: Runner | None = None,
) -> BedpostxOutputs:
    """
    Bayesian Estimation of Diffusion Parameters Obtained using Sampling Techniques
    (BEDPOST) for modeling multiple fibers per voxel.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        subject_dir: Input subject directory which contains bvals, bvecs, data,\
            and nodif_brain_mask files.
        num_fibres: Number of fibres per voxel (default 3).
        ard_weight: ARD weight, more weight means less secondary fibres per\
            voxel (default 1).
        burnin: Burnin period (default 1000).
        num_jumps: Number of jumps (default 1250).
        sample_every: Sample every (default 25).
        model_type: Deconvolution model. 1: with sticks, 2: with sticks with a\
            range of diffusivities (default), 3: with zeppelins.
        grad_nonlinear: Consider gradient nonlinearities, expects grad_dev in\
            the subject directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BedpostxOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BEDPOSTX_METADATA)
    cargs = []
    cargs.append("bedpostx")
    cargs.append(subject_dir)
    if num_fibres is not None:
        cargs.extend([
            "-n",
            str(num_fibres)
        ])
    if ard_weight is not None:
        cargs.extend([
            "-w",
            str(ard_weight)
        ])
    if burnin is not None:
        cargs.extend([
            "-b",
            str(burnin)
        ])
    if num_jumps is not None:
        cargs.extend([
            "-j",
            str(num_jumps)
        ])
    if sample_every is not None:
        cargs.extend([
            "-s",
            str(sample_every)
        ])
    if model_type is not None:
        cargs.extend([
            "-model",
            str(model_type)
        ])
    if grad_nonlinear:
        cargs.append("-g")
    ret = BedpostxOutputs(
        root=execution.output_file("."),
        xfms_output=execution.output_file(subject_dir + "_bedpostx/xfms/*"),
        diff_slices_output=execution.output_file(subject_dir + "_bedpostx/diff_slices/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BEDPOSTX_METADATA",
    "BedpostxOutputs",
    "bedpostx",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_INFLATION_METADATA = Metadata(
    id="36f016a31d3d3dcd623e236f9e609fe3ad4ba0fe.boutiques",
    name="surface-inflation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceInflationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_inflation(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """output surface file"""


def surface_inflation(
    anatomical_surface_in: InputPathType,
    surface_in: InputPathType,
    number_of_smoothing_cycles: int,
    smoothing_strength: float,
    smoothing_iterations: int,
    inflation_factor: float,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceInflationOutputs:
    """
    Surface inflation.
    
    Inflate a surface by performing cycles that consist of smoothing followed by
    inflation (to correct shrinkage caused by smoothing).
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        anatomical_surface_in: the anatomical surface.
        surface_in: the surface file to inflate.
        number_of_smoothing_cycles: number of smoothing cycles.
        smoothing_strength: smoothing strength (ranges [0.0 - 1.0]).
        smoothing_iterations: smoothing iterations.
        inflation_factor: inflation factor.
        surface_out: output surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceInflationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_INFLATION_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-inflation")
    cargs.append(execution.input_file(anatomical_surface_in))
    cargs.append(execution.input_file(surface_in))
    cargs.append(str(number_of_smoothing_cycles))
    cargs.append(str(smoothing_strength))
    cargs.append(str(smoothing_iterations))
    cargs.append(str(inflation_factor))
    cargs.append(surface_out)
    ret = SurfaceInflationOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_INFLATION_METADATA",
    "SurfaceInflationOutputs",
    "surface_inflation",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_WARP_DRIVE_METADATA = Metadata(
    id="0c165837a84160290a1d8256b9238ca4ea37da6a.boutiques",
    name="3dWarpDrive",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dWarpDriveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_warp_drive(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Warped dataset output"""
    output_summary: OutputPathType | None
    """Summary of calculations"""
    oned_output_file: OutputPathType | None
    """File with warping parameters"""
    matrix_output_file: OutputPathType | None
    """File with transformation matrices"""


def v_3d_warp_drive(
    dataset: InputPathType,
    base_dataset: InputPathType,
    prefix: str,
    shift_only: bool = False,
    shift_rotate: bool = False,
    shift_rotate_scale: bool = False,
    affine_general: bool = False,
    bilinear_general: bool = False,
    linear: bool = False,
    cubic: bool = False,
    nn: bool = False,
    quintic: bool = False,
    input_dataset: InputPathType | None = None,
    verbosity_flag: bool = False,
    summary_file: str | None = None,
    max_iterations: int | None = None,
    delta: float | None = None,
    weight: str | None = None,
    convergence_thresh: float | None = None,
    twopass: bool = False,
    final_mode: str | None = None,
    parfix: list[str] | None = None,
    oned_file: InputPathType | None = None,
    float_format: bool = False,
    coarserot_init: bool = False,
    oned_matrix_save: InputPathType | None = None,
    sdu_order: bool = False,
    sud_order: bool = False,
    dsu_order: bool = False,
    dus_order: bool = False,
    usd_order: bool = False,
    uds_order: bool = False,
    supper_s_matrix: bool = False,
    slower_s_matrix: bool = False,
    ashift: bool = False,
    bshift: bool = False,
    runner: Runner | None = None,
) -> V3dWarpDriveOutputs:
    """
    Warp a dataset to match another one (the base) using an affine transformation.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input dataset.
        base_dataset: Load dataset as the base to which the input dataset will\
            be matched. This is a mandatory option.
        prefix: Sets the prefix of the output dataset. If 'NULL', no output\
            dataset is written.
        shift_only: 3 parameters (shifts).
        shift_rotate: 6 parameters (shifts + angles).
        shift_rotate_scale: 9 parameters (shifts + angles + scale factors).
        affine_general: 12 parameters (3 shifts + 3x3 matrix).
        bilinear_general: 39 parameters (3 + 3x3 + 3x3x3). Not implemented and\
            will never be.
        linear: Linear interpolation method.
        cubic: Cubic interpolation method.
        nn: Nearest neighbor interpolation method [default].
        quintic: Quintic interpolation method.
        input_dataset: Specify the input dataset anywhere in the command line\
            option list.
        verbosity_flag: Print out lots of information along the way.
        summary_file: Save summary of calculations into text file. If value is\
            '-', summary goes to stdout.
        max_iterations: Allow up to 'm' iterations for convergence.
        delta: Distance, in voxel size, used to compute image derivatives using\
            finite differences. [Default=1.0].
        weight: Set the weighting applied to each voxel proportional to the\
            brick specified here. [Default=computed by program from base].
        convergence_thresh: Set the convergence parameter to be RMS 't' voxels\
            movement between iterations. [Default=0.03].
        twopass: Do the parameter estimation in two passes, coarse-but-fast\
            first, then fine-but-slow second.
        final_mode: Set the final warp to be interpolated using 'mode'.
        parfix: Fix the n'th parameter of the warp model to the value 'v'. More\
            than one -parfix option can be used.
        oned_file: Write out the warping parameters to this file.
        float_format: Write output dataset in float format, even if input\
            dataset is short or byte.
        coarserot_init: Initialize shift+rotation parameters by a brute force\
            coarse search.
        oned_matrix_save: Save base-to-input transformation matrices in\
            specified file. If the file does not end in '.1D', the program will\
            append '.aff12.1D'.
        sdu_order: Set the order of the matrix multiplication for the affine\
            transformations (S=triangular shear, D=diagonal scaling matrix,\
            U=rotation matrix).
        sud_order: Set the order of the matrix multiplication for the affine\
            transformations (S=triangular shear, U=rotation matrix, D=diagonal\
            scaling matrix).
        dsu_order: Set the order of the matrix multiplication for the affine\
            transformations (D=diagonal scaling matrix, S=triangular shear,\
            U=rotation matrix).
        dus_order: Set the order of the matrix multiplication for the affine\
            transformations (D=diagonal scaling matrix, U=rotation matrix,\
            S=triangular shear).
        usd_order: Set the order of the matrix multiplication for the affine\
            transformations (U=rotation matrix, S=triangular shear, D=diagonal\
            scaling matrix).
        uds_order: Set the order of the matrix multiplication for the affine\
            transformations (U=rotation matrix, D=diagonal scaling matrix,\
            S=triangular shear).
        supper_s_matrix: Set the S matrix to be upper triangular.
        slower_s_matrix: Set the S matrix to be lower triangular.
        ashift: Apply the shift parameters after the matrix transformation.
        bshift: Apply the shift parameters before the matrix transformation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dWarpDriveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_WARP_DRIVE_METADATA)
    cargs = []
    cargs.append("3dWarpDrive")
    cargs.append(execution.input_file(dataset))
    cargs.extend([
        "-base",
        execution.input_file(base_dataset)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if shift_only:
        cargs.append("-shift_only")
    if shift_rotate:
        cargs.append("-shift_rotate")
    if shift_rotate_scale:
        cargs.append("-shift_rotate_scale")
    if affine_general:
        cargs.append("-affine_general")
    if bilinear_general:
        cargs.append("-bilinear_general")
    if linear:
        cargs.append("-linear")
    if cubic:
        cargs.append("-cubic")
    if nn:
        cargs.append("-NN")
    if quintic:
        cargs.append("-quintic")
    if input_dataset is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_dataset)
        ])
    if verbosity_flag:
        cargs.append("-verb")
    if summary_file is not None:
        cargs.extend([
            "-summ",
            summary_file
        ])
    if max_iterations is not None:
        cargs.extend([
            "-maxite",
            str(max_iterations)
        ])
    if delta is not None:
        cargs.extend([
            "-delta",
            str(delta)
        ])
    if weight is not None:
        cargs.extend([
            "-weight",
            weight
        ])
    if convergence_thresh is not None:
        cargs.extend([
            "-thresh",
            str(convergence_thresh)
        ])
    if twopass:
        cargs.append("-twopass")
    if final_mode is not None:
        cargs.extend([
            "-final",
            final_mode
        ])
    if parfix is not None:
        cargs.extend([
            "-parfix",
            *parfix
        ])
    if oned_file is not None:
        cargs.extend([
            "-1Dfile",
            execution.input_file(oned_file)
        ])
    if float_format:
        cargs.append("-float")
    if coarserot_init:
        cargs.append("-coarserot")
    if oned_matrix_save is not None:
        cargs.extend([
            "-1Dmatrix_save",
            execution.input_file(oned_matrix_save)
        ])
    if sdu_order:
        cargs.append("-SDU")
    if sud_order:
        cargs.append("-SUD")
    if dsu_order:
        cargs.append("-DSU")
    if dus_order:
        cargs.append("-DUS")
    if usd_order:
        cargs.append("-USD")
    if uds_order:
        cargs.append("-UDS")
    if supper_s_matrix:
        cargs.append("-Supper")
    if slower_s_matrix:
        cargs.append("-Slower")
    if ashift:
        cargs.append("-ashift")
    if bshift:
        cargs.append("-bshift")
    ret = V3dWarpDriveOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + "+orig"),
        output_summary=execution.output_file(summary_file) if (summary_file is not None) else None,
        oned_output_file=execution.output_file(pathlib.Path(oned_file).name) if (oned_file is not None) else None,
        matrix_output_file=execution.output_file(pathlib.Path(oned_matrix_save).name) if (oned_matrix_save is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dWarpDriveOutputs",
    "V_3D_WARP_DRIVE_METADATA",
    "v_3d_warp_drive",
]
